import type { Rule } from "eslint";

const rule: Rule.RuleModule = {
  meta: {
    type: "problem",
    docs: {
      description: "Disallow direct usage of `new PrismaClient()`",
      category: "Best Practices",
      recommended: true,
    },
  },
  create(context) {
    // Check if the file is the target file where the import is allowed
    if (context.filename.endsWith("src/utils/db.ts")) {
      return {};
    }

    return {
      NewExpression(node) {
        if (node.callee.type === "Identifier" && node.callee.name === "PrismaClient") {
          context.report({
            node,
            message:
              "Avoid direct usage of `new PrismaClient()`. Import from `src/utils/db.ts` instead.",
          });
        }
      },
    };
  },
};

export default rule;
